@@ -447,11 +447,14 @@ class RedisRoot:
             def django_fields_to_redis_fields(django_model, redis_root):
                 redis_fields = {}
                 for django_field in django_model._meta.get_fields():
-                    redis_field = django_field_to_redis_field(django_field, redis_root)
+                    django_field_name = django_field.name
+                    if django_field_name in ['id', 'pk']:
+                        django_field_name = 'django_id'
+                        redis_field = RedisNumber(null=False)
+                    else:
+                        redis_field = django_field_to_redis_field(django_field, redis_root)
+                    print(django_field, redis_field)
                     if redis_field:
-                        django_field_name = django_field.name
-                        if django_field_name in ['id', 'pk']:
-                            django_field_name = 'django_id'
                         redis_fields[django_field_name] = redis_field
                 return redis_fields
 
@@ -462,10 +465,11 @@ class RedisRoot:
 
             def django_field_to_redis_field(django_field, redis_root):
 
-                def get_allowed_params(django_field, redis_root):
+                def django_field_params_to_redis_field_params(django_field, redis_root):
                     allowed_params = ['null', 'default', 'choices', 'remote_field']
                     allowed_redis_params = {}
                     for django_field_param_name in django_field.__dict__.keys():
+                        redis_field_param_name = django_field_param_name
                         if django_field_param_name in allowed_params:
                             value = getattr(django_field, django_field_param_name)
                             if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH]:
@@ -479,10 +483,11 @@ class RedisRoot:
                                     real_value = None
                                 value = real_value
                             elif django_field_param_name == 'remote_field':
+                                redis_field_param_name = 'model'
                                 if value is not None:
                                     value = value.model
                                     value = get_or_create_redis_model_from_django_model(value, redis_root)
-                            allowed_redis_params[django_field_param_name] = value
+                            allowed_redis_params[redis_field_param_name] = value
                     return allowed_redis_params
 
                 field_mapping = {
@@ -508,6 +513,8 @@ class RedisRoot:
                     django_models.ManyToManyField: RedisManyToMany
                 }
 
+                print(django_field, django_field.__class__.__name__, django_field.__class__.__name__.endswith('Rel'))
+
                 if django_field.__class__.__name__.endswith('Rel'):
                     redis_field = None
                 elif django_field.__class__ in field_mapping.keys():
@@ -521,7 +528,9 @@ class RedisRoot:
                         (redis_field,),
                         {}
                     )
-                    redis_field = redis_field_class(**get_allowed_params(django_field, redis_root))
+
+                    redis_field_params = django_field_params_to_redis_field_params(django_field, redis_root)
+                    redis_field = redis_field_class(**redis_field_params)
                 return redis_field            
             
             def update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root):
